<?php

namespace Drupal\glidejs\Plugin\views\style;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\style\StylePluginBase;

/**
 * Style plugin to render a view using Glide.js.
 *
 * @ViewsStyle(
 *   id = "glide",
 *   title = @Translation("Glide Carousel"),
 *   help = @Translation("Displays rows in a Glide.js carousel."),
 *   theme = "views_view_style_glide",
 *   display_types = {"normal"}
 * )
 */
class GlideStyle extends StylePluginBase {

  /**
   * {@inheritdoc}
   */
  protected $usesRowPlugin = TRUE;

  /**
   * {@inheritdoc}
   */
  public function defineOptions() {
    $options = parent::defineOptions();
    $options['per_view'] = ['default' => 1];
    $options['type'] = ['default' => 'slider'];
    $options['autoplay'] = ['default' => FALSE];
    $options['autoplay_speed'] = ['default' => FALSE];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['type'] = [
      '#type' => 'select',
      '#title' => $this->t('Glide type'),
      '#default_value' => $this->options['type'],
      '#options' => [
        'carousel' => $this->t('Carousel'),
        'slider' => $this->t('Slider'),
      ],
      '#description' => $this->t('The type of Glide behavior.'),
    ];
    $form['per_view'] = [
      '#type' => 'number',
      '#title' => $this->t('Slides per view'),
      '#default_value' => $this->options['per_view'],
      '#min' => 1,
      '#description' => $this->t('Number of slides to show at once in the carousel.'),
    ];

    $form['autoplay'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Autoplay'),
      '#default_value' => $this->options['autoplay'],
      '#description' => $this->t('Automatically slide to the next item.'),
    ];

    $form['autoplay_speed'] = [
      '#type' => 'number',
      '#title' => $this->t('Autoplay speed (ms)'),
      '#default_value' => $this->options['autoplay_speed'],
      '#min' => 100,
      '#step' => 100,
      '#description' => $this->t('Change slides after a specified interval.'),
      '#states' => [
        'visible' => [
          ':input[name="style_options[autoplay]"]' => ['checked' => TRUE],
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();

    $autoplay = $this->options['autoplay'] ? (int) $this->options['autoplay_speed'] : FALSE;

    $build['#attached']['library'][] = 'glidejs/glide_external';
    $build['#attached']['library'][] = 'glidejs/glide';
    $build['#attached']['drupalSettings']['glidejs'] = [
      'type' => $this->options['type'],
      'perView' => $this->options['per_view'],
      'autoplay' => $autoplay,
      'viewId' => $this->view->id(),
    ];

    return $build;
  }
}
